.. LFS documentation master file, created by sphinx-quickstart on Wed Dec 17 19:36:02 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

===
LFS
===

Narrative documentation
=======================


.. toctree::
   :maxdepth: 2

   narrative/features.rst
   narrative/customer.rst
   narrative/shipping.rst
   narrative/category.rst

API
===

.. toctree::
   :maxdepth: 1

   api/cart.rst
   api/customer.rst
   api/payment.rst
   api/shipping.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`

